@@ -12,17 +12,23 @@ from polarion_rest_api_client.open_api_client.api.test_runs import (
 )
 
 from . import base_classes as bc
-from . import test_records
+from . import test_parameters, test_records
 
 if t.TYPE_CHECKING:
     from polarion_rest_api_client import client as polarion_client
 
+AttributesType = t.TypeVar(
+    "AttributesType",
+    bound=api_models.TestrunsListPostRequestDataItemAttributes
+    | api_models.TestrunsSinglePatchRequestDataAttributes,
+)
+
 
 class TestRuns(
     bc.SingleUpdatableItemsMixin[dm.TestRun],
     bc.UpdatableItemsClient[dm.TestRun],
 ):
-    def get(self, *args, **kwargs) -> dm.TestRun:
+    def get(self, *args: t.Any, **kwargs: t.Any) -> dm.TestRun:
         raise NotImplementedError
 
     def __init__(
@@ -30,8 +36,9 @@ class TestRuns(
     ):
         super().__init__(project_id, client)
         self.records = test_records.TestRecords(project_id, client)
+        self.parameters = test_parameters.TestRunParameters(project_id, client)
 
-    def _update(self, to_update: list[dm.TestRun] | dm.TestRun):
+    def _update(self, to_update: list[dm.TestRun] | dm.TestRun) -> None:
         """Create the given list of test runs."""
         assert not isinstance(to_update, list), "Expected only one item"
         assert to_update.id
@@ -41,7 +48,7 @@ class TestRuns(
             client=self._client.client,
             body=api_models.TestrunsSinglePatchRequest(
                 data=api_models.TestrunsSinglePatchRequestData(
-                    type=api_models.TestrunsSinglePatchRequestDataType.TESTRUNS,  # pylint: disable=line-too-long
+                    type_=api_models.TestrunsSinglePatchRequestDataType.TESTRUNS,  # pylint: disable=line-too-long
                     id=f"{self._project_id}/{to_update.id}",
                     attributes=self._fill_test_run_attributes(
                         api_models.TestrunsSinglePatchRequestDataAttributes,
@@ -59,7 +66,7 @@ class TestRuns(
         *,
         page_size: int = 100,
         page_number: int = 1,
-        fields: t.Optional[dict[str, str]] = None,
+        fields: dict[str, str] | None = None,
     ) -> tuple[list[dm.TestRun], bool]:
         """Return the test runs on a defined page matching the given query.
 
@@ -95,7 +102,7 @@ class TestRuns(
             test_runs.append(
                 dm.TestRun(
                     data.id.split("/")[-1],
-                    self.unset_to_none(data.attributes.type),
+                    self.unset_to_none(data.attributes.type_),
                     self.unset_to_none(data.attributes.status),
                     self.unset_to_none(data.attributes.title),
                     self._handle_text_content(
@@ -125,11 +132,11 @@ class TestRuns(
 
         return test_runs, next_page
 
-    def _create(self, items: list[dm.TestRun]):
+    def _create(self, items: list[dm.TestRun]) -> None:
         """Create the given list of test runs."""
         polarion_test_runs = [
             api_models.TestrunsListPostRequestDataItem(
-                type=api_models.TestrunsListPostRequestDataItemType.TESTRUNS,
+                type_=api_models.TestrunsListPostRequestDataItemType.TESTRUNS,
                 attributes=self._fill_test_run_attributes(
                     api_models.TestrunsListPostRequestDataItemAttributes,
                     test_run,
@@ -145,30 +152,26 @@ class TestRuns(
         )
 
         self._raise_on_error(response)
-        assert (
-            isinstance(response.parsed, api_models.TestrunsListPostResponse)
-            and response.parsed.data
-        )
+        assert isinstance(response.parsed, api_models.TestrunsListPostResponse)
+        assert response.parsed.data
+
         if response.parsed and response.parsed.data:
             for i, data in enumerate(response.parsed.data):
                 assert data.id
                 items[i].id = data.id.split("/")[-1]
 
-    def _delete(self, items: dm.TestRun | list[dm.TestRun]):
+    def _delete(self, items: dm.TestRun | list[dm.TestRun]) -> None:
         raise NotImplementedError
 
-    def _fill_test_run_attributes(
+    def _fill_test_run_attributes(  # noqa: C901
         self,
-        attributes_type: type[
-            api_models.TestrunsListPostRequestDataItemAttributes
-            | api_models.TestrunsSinglePatchRequestDataAttributes
-        ],
+        attributes_type: type[AttributesType],
         test_run: dm.TestRun,
-    ):
+    ) -> AttributesType:
         type_prefix = attributes_type.__name__
         attributes = attributes_type()
         if test_run.type is not None:
-            attributes.type = test_run.type
+            attributes.type_ = test_run.type
         if test_run.id and hasattr(attributes, "id"):
             attributes.id = test_run.id
         if test_run.status is not None:
@@ -205,7 +208,7 @@ class TestRuns(
             )()
             assert attributes.home_page_content
             if test_run.home_page_content.type:
-                attributes.home_page_content.type = getattr(
+                attributes.home_page_content.type_ = getattr(
                     api_models, f"{type_prefix}HomePageContentType"
                 )(test_run.home_page_content.type)
             if test_run.home_page_content.value:
@@ -213,4 +216,4 @@ class TestRuns(
                     test_run.home_page_content.value
                 )
 
-        return attributes
+        return t.cast(AttributesType, attributes)
