@@ -321,6 +321,16 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             ),
             status=work_item.status or oa_types.UNSET,
             title=work_item.title or oa_types.UNSET,
+            hyperlinks=oa_types.UNSET
+            if work_item.hyperlinks is None
+            else [
+                api_models.WorkitemsListPostRequestDataItemAttributesHyperlinksItem(
+                    role=hyperlink.role or oa_types.UNSET,
+                    title=hyperlink.title or oa_types.UNSET,
+                    uri=hyperlink.uri or oa_types.UNSET,
+                )
+                for hyperlink in work_item.hyperlinks
+            ],
         )
 
         attrs.additional_properties.update(work_item.additional_attributes)
@@ -367,6 +377,16 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         if work_item.status is not None:
             attrs.status = work_item.status
 
+        if work_item.hyperlinks is not None:
+            attrs.hyperlinks = [
+                api_models.WorkitemsSinglePatchRequestDataAttributesHyperlinksItem(
+                    role=hyperlink.role or oa_types.UNSET,
+                    title=hyperlink.title or oa_types.UNSET,
+                    uri=hyperlink.uri or oa_types.UNSET,
+                )
+                for hyperlink in work_item.hyperlinks
+            ]
+
         attrs.additional_properties.update(work_item.additional_attributes)
 
         return api_models.WorkitemsSinglePatchRequest(
@@ -453,6 +473,9 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
                         link.id or "",
                         link.additional_properties.get("suspect", False),
                         work_item_id,
+                        link.additional_properties.get(
+                            "revision", oa_types.UNSET
+                        ),
                     )
                     for link in link_data.data or []
                 ]
@@ -477,10 +500,23 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
         description = None
         if work_item.attributes.description:
             description = dm.TextContent(
-                self.unset_to_none(work_item.attributes.description.type_),
+                None
+                if work_item.attributes.description.type_ is oa_types.UNSET
+                else str(work_item.attributes.description.type_),
                 self.unset_to_none(work_item.attributes.description.value),
             )
 
+        hyperlinks = None
+        if isinstance(work_item.attributes.hyperlinks, list):
+            hyperlinks = [
+                dm.HyperLink(
+                    role=self.unset_to_none(hyperlink.role),
+                    title=self.unset_to_none(hyperlink.title),
+                    uri=self.unset_to_none(hyperlink.uri),
+                )
+                for hyperlink in work_item.attributes.hyperlinks
+            ]
+
         return work_item_cls(
             work_item_id,
             title=self.unset_to_none(work_item.attributes.title),
@@ -493,4 +529,5 @@ class WorkItems(bc.SingleUpdatableItemsMixin, bc.StatusItemClient):
             linked_work_items_truncated=links_truncated,
             attachments_truncated=attachments_truncated,
             home_document=home_document,
+            hyperlinks=hyperlinks,
         )
