@@ -7,7 +7,7 @@ from enum import Enum
 class WorkitemsSingleGetResponseDataRelationshipsApprovalsDataItemType(
     str, Enum
 ):
-    WORKRECORDS = "workrecords"
+    WORKITEM_APPROVALS = "workitem_approvals"
 
     def __str__(self) -> str:
         return str(self.value)
